extends Node


const file_path: String = "user://data.save"


func save_game():
	var save_file = FileAccess.open(file_path, FileAccess.WRITE)
	var save_nodes = get_tree().get_nodes_in_group("save_data")
	var json_data: Dictionary = {}
	
	for node in save_nodes:
		if !node.has_method("save_data"):
			print("node '%s' is missing a save function" % node.name)
			continue
		
		json_data.merge(node.call("save_data"))
	
	save_file.store_line(JSON.stringify(json_data))


func load_game():
	if not FileAccess.file_exists(file_path):
		print("Save file not exist")
		return
	
	var save_file = FileAccess.open(file_path, FileAccess.READ)
	var save_nodes = get_tree().get_nodes_in_group("save_data")
	
	while save_file.get_position() < save_file.get_length():
		var json_string = save_file.get_line()
		var json = JSON.new()
		
		if not json.parse(json_string) == OK:
			print("JSON Parse Error: ", json.get_error_message(), " at line ", json.get_error_line())
			continue
		
		var json_data: Dictionary = json.get_data()
		
		for node in save_nodes:
			if !node.has_method("load_data"):
				print("node '%s' is missing a load function" % node.name)
				continue
			
			node.call("load_data", json_data)
